@@ -134,7 +134,7 @@ class accuinsight(object):
         channel_id = self.channel_id
         
         print('global variable')
-        print(message, thresholds, token, channel_id)
+        print(message)
         print(thresholds)
         print(token)
         print(channel_id)
@@ -350,10 +350,10 @@ class accuinsight(object):
                 clear_runs(start_ts, end_ts, delta_ts)
                 accuinsight._send_message(metric=self.monitor,
                                           current_value=self.current_value,
-                                          message=self.message,
-                                          thresholds=self.thresholds,
-                                          token=self.token,
-                                          channel_id=self.channel_id)
+                                          message=message,
+                                          thresholds=thresholds,
+                                          token=token,
+                                          channel_id=channel_id)
                 modeler_rest = LifecycleRestApi(LcConst.BACK_END_API_URL,
                                                 LcConst.BACK_END_API_PORT,
                                                 LcConst.BACK_END_API_URI)
@@ -501,14 +501,23 @@ class accuinsight(object):
     
         
         print('send_message function')
-        print(message, thresholds, token, channel_id)
+        print(message)
         print(thresholds)
         print(token)
         print(channel_id)
         
         
         if token is not None and channel_id is not None:
+        
+        
+            print('pass_1')
+        
             if thresholds is not None:
+                
+                
+                print('pass_thresholds')
+                            
+                            
                 try:
                     if current_value >= thresholds:
                         msg = '[모델 학습 완료] ' + metric + '이 설정하신 thresolds: ' + str(thresholds) + '를 초과하였습니다.'
@@ -516,12 +525,17 @@ class accuinsight(object):
                 except SlackApiError as e:
                     assert e.response["error"]
             elif message is not None:
+                
                 try:
+                    print('pass_message')
                     msg = message
                     response = WebClient(token=token).chat_postMessage(channel=channel_id, text=msg)
                 except SlackApiError as e:
                     assert e.response["error"]
         else:
+            
+            print('pass_else')
+            
             pass
 
     def _off_autolog():
